<?php
/**
 * FlexiTheme.php
 * FlexiPanel theme framework by FlexiThemes.com
*/

class FlexiTheme
{
    var $theme_name = false;
    var $theme_options_name = false;
    var $options;
    var $widgets_options = array();
    var $head_css_source;
    var $head_js_source;
    var $footer_js_source;
    var $flexipanel_options = array();
    var $flexipanel_options_file = false;
    var $post_meta_elements = array(
        'date' => 'Date',
        'author' => 'Author',
        'comments' => 'Comments number & link',
        'categories' => 'Categories list',
        'tags' => 'Tags list',
        'thumbnail' => 'Thumbnail',
        'readmore' => '"Read More" link/button'
    );
    var $includes = array('common', 'menus/menus');
    var $widgets = array('ads', 'banners-125', 'comments', 'posts', 'search', 'social-connect', 'social-share', 'tabs', 'text', 'tweets');
    
    function FlexiTheme()
    {
        if (!defined('FLEXIPANEL_DIR')) {
            define('FLEXIPANEL_DIR', 'flexipanel');
        }
        define('FLEXIPANEL_PATH', TEMPLATEPATH . '/' . FLEXIPANEL_DIR);
        define('FLEXIPANEL_URL', get_bloginfo('template_url') . '/' . FLEXIPANEL_DIR);
        
        if (!defined('FLEXIPANEL_WIDGETS_DIR')) {
            define('FLEXIPANEL_WIDGETS_DIR', 'flexipanel/widgets');
        }
        define('FLEXIPANEL_WIDGETS_PATH', TEMPLATEPATH . '/' . FLEXIPANEL_WIDGETS_DIR);
        define('FLEXIPANEL_WIDGETS_URL', get_bloginfo('template_url') . '/' . FLEXIPANEL_WIDGETS_DIR);
    }
    
    function loadFlexiPanel()
    {
        $this->load_options();
        
        if(file_exists(TEMPLATEPATH . '/includes/widgets-options.php')) {
            include (TEMPLATEPATH . '/includes/widgets-options.php');
        }
        
        $this->loadIncludes();
        $this->loadWidgets();
        
        if($this->head_css_source || $this->head_js_source || $this->display('custom_css')) {
            $this->add_hook('head', array(&$this, 'load_head_css_js'), 20);
        }
        
        if($this->footer_js_source) {
            $this->add_hook('body_after', array(&$this, 'load_footer_js'), 20);
        }
        
        if(is_admin()) {
            include (FLEXIPANEL_PATH . '/FlexiPanel.php');
            new FlexiPanel();
        } 
    }
    
    function load_options()
    {
        if($this->theme_name) {
            $this_theme_name = $this->theme_name;
        } else {
            $theme_data = get_theme_data(TEMPLATEPATH . '/style.css');
            $this_theme_name = $theme_data['Name'];
            $this->theme_name = $this_theme_name;
        }
        
        if($this->theme_options_name) {
            $this_theme_options_name = $this->theme_options_name;
        } else {
            $this_theme_options_name = str_replace(' ', '_', strtolower( trim($this_theme_name) ) ) . '_theme_options';
            $this->theme_options_name = $this_theme_options_name;
        }
        
        $get_theme_options = get_option($this_theme_options_name);
        $this->options = $get_theme_options ? $get_theme_options : false; 
    }
    
    function option($name) 
    {
        echo $this->get_option($name);
    }
    
    function get_option($name) 
    {
        $return_option = '';
        if(isset($this->options[$name])) {
            if(is_array($this->options[$name])) {
                $return_option = $this->options[$name];
            } else {
                $return_option = stripslashes($this->options[$name]);
            }
        } 
        return $return_option;
    }
    
    function display($name, $content = false) 
    {
        $option_enabled = strlen($this->get_option($name)) > 0 ? true : false;
        if(!$content) {
            return $option_enabled;
        } elseif($option_enabled) {
            echo $content;
        }
    }
    
    
    function display_a($item, $name, $content = false) 
    {
        $get_option = is_array($name) ? $name : $this->get_option($name);
        if(is_array($get_option)) {
            $option_enabled = in_array($item, $get_option) ? true : false;
            if(!$content) {
                return $option_enabled;
            } elseif($option_enabled) {
                echo $content;
            }
            
        } else {
            return false;
        }
    }
    
    function flexipanel_option($menu, $submenu, $title, $name = false, $type = false, $value = '', $attributes = array())
    {
        if(is_admin()) {
            
            if(is_array($menu)) {
                $menu_title = isset($menu['0']) ? $menu['0'] : $menu;
                $menu_priority = isset($menu['1']) ? $menu['1'] : false;
                $menu_icon = isset($menu['2']) ? $menu['2'] : false;
            } else {
                $menu_title = $menu;
                $menu_priority = false;
                $menu_icon = false;
            }
            
            if(is_array($submenu)) {
                $submenu_title = isset($submenu['0']) ? $submenu['0'] : $submenu;
                $submenu_priority =  isset($submenu['1']) ? $submenu['1'] : false;
                $submenu_display =  isset($submenu['2'])  ? $submenu['2'] : false;
            } else {
                $submenu_title = $submenu;
                $submenu_priority = false;
                $submenu_display = false;
            }
            
            if($menu_priority) {
                $this->flexipanel_options[$menu_title]['priority'] = $menu_priority;
            }
            
            if($menu_icon) {
                $this->flexipanel_options[$menu_title]['icon'] = $menu_icon;
            }
            
            if($submenu_priority) {
                $this->flexipanel_options[$menu_title]['content'][$submenu_title]['priority'] = $submenu_priority;
            }
            
            if($submenu_display) {
                $this->flexipanel_options[$menu_title]['content'][$submenu_title]['display'] = $submenu_display;
                $this->flexipanel_options[$menu_title]['content'][$submenu_title]['link_title'] = $submenu_title;
                $this->flexipanel_options[$menu_title]['content'][$submenu_title]['link_url'] = $title;
            } 
            
            if($name && $type) {
                $element_args['title'] = $title;
                $element_args['name'] = $name;
                $element_args['type'] = $type;
                $element_args['value'] = $value;
                
                if(count($attributes) > 0) {
                    foreach($attributes as $attributekey=>$attributeval) {
                        $element_args[$attributekey] = $attributeval;
                    }
                }
                $this->flexipanel_options[$menu_title]['content'][$submenu_title]['content'][$element_args['name']]['content'] = $element_args;
    
                if($attributes['priority']) {
                    $this->flexipanel_options[$menu_title]['content'][$submenu_title]['content'][$element_args['name']]['priority'] = $attributes['priority'];
                }
            }
        }
    }
    
    function hook($tag, $arg = '')
    {
         do_action('flexipanel_' . $tag, $arg); 
    }
    
    function add_hook($tag, $function_to_add, $priority = 10, $accepted_args = 1)
    {
         add_action( 'flexipanel_' . $tag, $function_to_add, $priority, $accepted_args ); 
    }
    
    function head_css($source = false) 
    {
        if($source) {
            $this->head_css_source .= $source . "\n";
        }
    }
    
    function head_js($source = false) 
    {
        if($source) {
            $this->head_js_source .= $source . "\n";
        }
    }
    
    function footer_js($source = false) 
    {
        if($source) {
            $this->footer_js_source .= $source . "\n";
        }
    }
    
    function load_head_css_js()
    {
        if($this->display('custom_css')) {
            $this->head_css($this->get_option('custom_css'));
        }
        $return = "\n";
        if($this->head_css_source) {
            $return .= '<style type="text/css">' . "\n";
            $return .= '<!--' . "\n";
            $return .= $this->head_css_source;
            $return .= '-->' . "\n";
            $return .= '</style>' . "\n\n";

        }
        
        if($this->head_js_source) {
            $return .= "<script type='text/javascript'>\n";
            $return .= '/* <![CDATA[ */' . "\n";
            $return .= $this->head_js_source;
            $return .= '/* ]]> */' . "\n";
            $return .= '</script>' . "\n\n";
        }
        echo $return;
    }
    
    function load_footer_js()
    {
        $return = "\n";

        if($this->footer_js_source) {
            $return .= "<script type='text/javascript'>\n";
            $return .= '/* <![CDATA[ */' . "\n";
            $return .= $this->footer_js_source;
            $return .= '/* ]]> */' . "\n";
            $return .= '</script>' . "\n\n";
        }
        echo $return;
    }
    
    function addIncludes($new_includes = array())
    {
       $update_includes = array_merge($this->includes, $new_includes);
       $this->includes = $update_includes;
    } 
    
    function loadIncludes()
    {
        foreach($this->includes as $include) {
            include (TEMPLATEPATH . '/includes/' . $include . '.php');
        }
    }  
    
    function loadWidgets()
    {
        foreach($this->widgets as $widget) {
            include (FLEXIPANEL_WIDGETS_PATH . '/' . $widget . '.php');
        }
    }
       
    /*
        General Functions
    */
    
    function request ($var)
    {
        if (strlen($_REQUEST[$var]) > 0) {
            return preg_replace('/[^A-Za-z0-9-_]/', '', $_REQUEST[$var]);
        } else {
            return false;
        }
    }
    
    function get_pages_array($query = '', $pages_array = array())
    {
    	$pages = get_pages($query); 
        
    	foreach ($pages as $page) {
    		$pages_array[$page->ID] = $page->post_title;
    	  }
    	return $pages_array;
    }
    
    function get_page_name($page_id)
    {
    	global $wpdb;
    	$page_name = $wpdb->get_var("SELECT post_title FROM $wpdb->posts WHERE ID = '".$page_id."' && post_type = 'page'");
    	return $page_name;
    }
    
    function get_page_id($page_name){
        global $wpdb;
        $the_page_name = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE post_name = '" . $page_name . "' && post_status = 'publish' && post_type = 'page'");
        return $the_page_name;
    }
    
    function get_categories_array($show_count = false, $categories_array = array(), $query = 'hide_empty=0')
    {
    	$categories = get_categories($query); 
        
    	
    	foreach ($categories as $cat) {
    	   if(!$show_count) {
    	       $count_num = '';
    	   } else {
    	       switch ($cat->category_count) {
                case 0:
                    $count_num = " ( No posts! )";
                    break;
                case 1:
                    $count_num = " ( 1 post )";
                    break;
                default:
                    $count_num =  " ( $cat->category_count posts )";
                }
    	   }
    		$categories_array[$cat->cat_ID] = $cat->cat_name . $count_num;
    	  }
    	return $categories_array;
    }

    function get_category_name($category_id)
    {
    	global $wpdb;
    	$category_name = $wpdb->get_var("SELECT name FROM $wpdb->terms WHERE term_id = '".$category_id."'");
    	return $category_name;
    }
    
    
    function get_category_id($category_name)
    {
    	global $wpdb;
    	$category_id = $wpdb->get_var("SELECT term_id FROM $wpdb->terms WHERE name = '" . addslashes($category_name) . "'");
    	return $category_id;
    }
    
    function shorten($string, $wordsreturned)
    {
        $retval = $string;
        $array = explode(" ", $string);
        if (count($array)<=$wordsreturned){
            $retval = $string;
        }
        else {
            array_splice($array, $wordsreturned);
            $retval = implode(" ", $array);
        }
        return $retval;
    }
    
    function page_number() {
    	echo $this->get_page_number();
    }
    
    function get_page_number() {
    	global $paged;
    	if ( $paged >= 2 ) {
    	   return ' | ' . sprintf( __( 'Page %s', 'flexithemes' ), $paged );
    	}
    }
    
    function meta_title()
    {
        if ( is_single() ) { 
			single_post_title(); echo ' | '; bloginfo( 'name' );
		} elseif ( is_home() || is_front_page() ) {
			bloginfo( 'name' );
			if( get_bloginfo( 'description' ) ) {
		      echo ' | ' ; bloginfo( 'description' ); $this->page_number();
			}
		} elseif ( is_page() ) {
			single_post_title( '' ); echo ' | '; bloginfo( 'name' );
		} elseif ( is_search() ) {
			printf( __( 'Search results for %s', 'flexithemes' ), '"'.get_search_query().'"' );  $this->page_number(); echo ' | '; bloginfo( 'name' );
		} elseif ( is_404() ) { 
			_e( 'Not Found', 'flexithemes' ); echo ' | '; bloginfo( 'name' );
		} else { 
			wp_title( '' ); echo ' | '; bloginfo( 'name' ); $this->page_number();
		}
    }
    
    function rss_url()
    {
        $the_rss_url = $this->display('rss_url') ? $this->get_option('rss_url') : get_bloginfo('rss2_url');
        return $the_rss_url;
    }
}
?>