<?php
/**
 * Make theme available for translation
 */
    load_theme_textdomain( 'flexithemes', TEMPLATEPATH . '/languages' );
    
/**
 * This theme uses post thumbnails
 */
    if(function_exists('add_theme_support')) {
        add_theme_support( 'post-thumbnails' );
    }
    
/**
 * This theme allows users to set a custom background
 */
    if(function_exists('add_custom_background')) {
        add_custom_background();
    }
    
/**
 * Clean out the exerpts
 */
    function new_excerpt_more($more) 
    {
    	return '';
    }
    add_filter('excerpt_more', 'new_excerpt_more');

    function new_excerpt_more_wp_older($excerpt) 
    {
    	return str_replace('[...]', '', $excerpt);
    }
    add_filter('wp_trim_excerpt', 'new_excerpt_more_wp_older');
 
/**
 * Load the css framework
 */
    function flexithemes_meta()
    {
        $return = '<link rel="stylesheet" href="' . get_bloginfo('template_url') . '/includes/css/screen.css" type="text/css" media="screen, projection" />' . "\n";
        $return .= '<link rel="stylesheet" href="' . get_bloginfo('template_url') . '/includes/css/print.css" type="text/css" media="print" />' . "\n";
        $return .= '<!--[if IE]><link rel="stylesheet" href="' . get_bloginfo('template_url') . '/includes/css/ie.css" type="text/css" media="screen, projection"><![endif]-->' . "\n";
        echo $return;
    }
    $this->add_hook('meta', 'flexithemes_meta');
    
/**
 * Load the default head elements
 */
    function flexithemes_head()
    {
        global $theme;
        $return = "<!--[if IE 6]>\n";
        $return .= "<script type='text/javascript' src=\"" . get_bloginfo('template_url') . "/includes/js/pngfix.js\"></script>\n";
        $return .= "<script type='text/javascript'>DD_belatedPNG.fix('img');</script>\n";
        $return .= "<![endif]-->\n";
        $return .= '<link rel="alternate" type="application/rss+xml" title="' . get_bloginfo('name') . ' RSS Feed" href="' . $theme->rss_url() . '" />' . "\n";
        $return .= '<link rel="pingback" href="' . get_bloginfo( 'pingback_url' ) . '" />' . "\n";
        
        $return .= '<link rel="stylesheet" href="' . get_bloginfo('template_url') . '/style-widgets.css" type="text/css" media="all" />' . "\n"; 
        
        if(function_exists('wp_pagenavi')) {
            $return .= '<link rel="stylesheet" href="' . get_bloginfo('template_url') . '/includes/css/wp-pagenavi.css" type="text/css" media="all" />' . "\n";   
        }
        if($theme->display('favicon')) {
            $return .= '<link rel="shortcut icon" href="' . $theme->get_option('favicon') . '" type="image/x-icon" />' . "\n";
        }
        echo $return;
    }
    $this->add_hook('head', 'flexithemes_head');

/**
 * Head Code
 */    
    function flexithemes_head_code()
    {
        global $theme;
        $theme->option('head_code'); echo "\n";
    }
    
    if($this->display('head_code')) {
        $this->add_hook('head', 'flexithemes_head_code', 100);
    }

/**
 * Footer Code
 */       
    function flexithemes_footer_code()
    {
        global $theme;
        $theme->option('footer_code');  echo "\n";
    }
    
    if($this->display('footer_code')) {
            $this->add_hook('body_after', 'flexithemes_footer_code', 100);
    }

/**
 * Top Right Searchbox
 */  
    if($this->display('topsearch')) {
        function flexithemes_topsearch_primary_menu_before()
        {
            echo "<div class=\"span-16\">\n";
        }
        
        function flexithemes_topsearch_primary_menu_after()
        {
            echo "</div>\n<div class=\"span-8 last\">\n<div id=\"topsearch\">\n";
            get_search_form();
            echo "</div>\n</div>\n";
        }
        
        function flexithemes_topsearch()
        {
            echo "<div class=\"span-24\">\n<div id=\"topsearch\">\n";
            get_search_form();
            echo "</div>\n</div>\n";
        }
        
        if($this->display('primary_menu')) {
            $this->add_hook('primary_menu_before', 'flexithemes_topsearch_primary_menu_before');
            $this->add_hook('primary_menu_after', 'flexithemes_topsearch_primary_menu_after');
        } else {
            $this->add_hook('topsearch', 'flexithemes_topsearch');
        }
    }

/**
 * Different background if the top search box and primary menu are disabled
 */   
    if(!$this->display('topsearch') && !$this->display('primary_menu') && !get_background_image()) {
        $this->head_css("body { background-image:url(" . get_bloginfo('template_url') . "/images/background-no-menu.png); }");
    }
    
    
/**
 * Apply the custom colors set from FlexiPanel
 */
    
    $flexithemes_colors = '';
    
    // Text Colors
    if($this->display('default_text_color')) {
        $flexithemes_colors .= "body {\n\tcolor: #" . $this->get_option('default_text_color') .";\n}\n\n";
    }
    
    if($this->display('post_content_color')) {
        $flexithemes_colors .= ".entry {\n\tcolor: #" . $this->get_option('post_content_color') .";\n}\n\n";
    }
    
    if($this->display('sidebar_text_color')) {
        $flexithemes_colors .= ".sidebar {\n\tcolor: #" . $this->get_option('sidebar_text_color') .";\n}\n\n";
    }
    
    if($this->display('widget_title_text_color')) {
        $flexithemes_colors .= ".widget-wrap h3.widget-title {\n\tcolor: #" . $this->get_option('widget_title_text_color') .";\n}\n\n";
    }
    
    
    if($this->display('footer_text_color')) {
        $flexithemes_colors .= "#footer {\n\tcolor: #" . $this->get_option('footer_text_color') .";\n}\n\n";
    }
    
    if($this->display('footer_copyright_text_color')) {
        $flexithemes_colors .= "#copyrights {\n\tcolor: #" . $this->get_option('footer_copyright_text_color') .";\n}\n\n";
    }
    
    // Links Colors
    if($this->display('main_links_color')) {
        $flexithemes_colors .= "a {\n\tcolor: #" . $this->get_option('main_links_color') .";\n}\n\n";
    }
    
    if($this->display('main_links_hover_color')) {
        $flexithemes_colors .= "a:hover {\n\tcolor: #" . $this->get_option('main_links_hover_color') .";\n}\n\n";
    }
    
    if($this->display('site_title_color')) {
        $flexithemes_colors .= "#site-title a {\n\tcolor: #" . $this->get_option('site_title_color') .";\n}\n\n";
    }
    
    if($this->display('site_title_hover_color')) {
        $flexithemes_colors .= "#site-title a:hover {\n\tcolor: #" . $this->get_option('site_title_hover_color') .";\n}\n\n";
    }
    
    if($this->display('post_title_color')) {
        $flexithemes_colors .= ".title a {\n\tcolor: #" . $this->get_option('post_title_color') .";\n}\n\n";
    }
    
    if($this->display('post_title_hover_color')) {
        $flexithemes_colors .= ".title a:hover {\n\tcolor: #" . $this->get_option('post_title_hover_color') .";\n}\n\n";
    }
    
    if($this->display('sidebar_widget_color')) {
        $flexithemes_colors .= ".widget a {\n\tcolor: #" . $this->get_option('sidebar_widget_color') .";\n}\n\n";
    }
    
    if($this->display('sidebar_widget_hover_color')) {
        $flexithemes_colors .= ".widget a:hover {\n\tcolor: #" . $this->get_option('sidebar_widget_hover_color') .";\n}\n\n";
    }
    
    if($this->display('footer_color')) {
        $flexithemes_colors .= "#copyrights a {\n\tcolor: #" . $this->get_option('footer_color') .";\n}\n\n";
    }
    
    if($this->display('footer_hover_color')) {
        $flexithemes_colors .= "#copyrights a:hover {\n\tcolor: #" . $this->get_option('footer_hover_color') .";\n}\n\n";
    }
    
    // Layout Colors
    if($this->display('body_background_color')) {
        $flexithemes_colors .= "body {\n\tbackground-color: #" . $this->get_option('body_background_color') .";\n}\n\n";
    }
    
    if($this->display('container_background_color')) {
        $flexithemes_colors .= "#container {\n\tbackground-color: #" . $this->get_option('container_background_color') .";\n}\n\n";
    }
    
    if($this->display('header_background_color')) {
        $flexithemes_colors .= "#header {\n\tbackground-color: #" . $this->get_option('header_background_color') .";\n}\n\n";
    }
    
    if($this->display('sidebar_background_color')) {
        $flexithemes_colors .= ".sidebar {\n\tbackground-color: #" . $this->get_option('sidebar_background_color') .";\n}\n\n";
    }
    
    if($this->display('footer_background_color')) {
        $flexithemes_colors .= "#footer {\n\tbackground-color: #" . $this->get_option('footer_background_color') .";\n}\n\n";
    }
    
    if($this->display('main_content_background_color')) {
        $flexithemes_colors .= "#main {\n\tbackground-color: #" . $this->get_option('main_content_background_color') .";\n}\n\n";
    }
    
    if($this->display('posts_background_color')) {
        $flexithemes_colors .= ".postwrap {\n\tbackground-color: #" . $this->get_option('posts_background_color') .";\n}\n\n";
    }
    
    if($this->display('thumbnails_background_color')) {
        $flexithemes_colors .= ".post_thumbnail {\n\tbackground-color: #" . $this->get_option('thumbnails_background_color') .";\n}\n\n";
    }
    
    if($this->display('thumbnails_border_color')) {
        $flexithemes_colors .= ".post_thumbnail {\n\tborder-color: #" . $this->get_option('thumbnails_border_color') .";\n}\n";
    }
    
    if($flexithemes_colors) {
        $apply_flexithemes_colors = "/* Flexipanel Custom Colors */\n";
        $apply_flexithemes_colors .= $flexithemes_colors;
        $apply_flexithemes_colors .= "/* End Flexipanel Custom Colors */\n";
        $this->head_css($apply_flexithemes_colors);
    }
?>