<?php

/*-----------------------------------------------------------------------------------*/
/* Options Framework Functions
/*-----------------------------------------------------------------------------------*/

if ( STYLESHEETPATH == TEMPLATEPATH ) {
	define('OF_FILEPATH', TEMPLATEPATH);
	define('OF_DIRECTORY', get_bloginfo('template_directory'));
} else {
	define('OF_FILEPATH', STYLESHEETPATH);
	define('OF_DIRECTORY', get_bloginfo('stylesheet_directory'));
}

require_once (OF_FILEPATH . '/admin/admin-functions.php');
require_once (OF_FILEPATH . '/admin/admin-interface.php');
require_once (OF_FILEPATH . '/admin/theme-options.php');
require_once (OF_FILEPATH . '/admin/theme-functions.php');




/*-----------------------------------------------------------------------------------*/
/* Check for Cart66
/*-----------------------------------------------------------------------------------*/
if (get_option('of_commerce_select') == "0") {
	cart66_check();
}

function cart66_check()
{
	if ( !class_exists('Cart66') )
	{
		add_action('admin_notices', 'cart66_check_notice');
	}
}


function cart66_check_notice()
{
?>
	<div class='updated fade'>
		<p>The Cart66 commerce plugin is required for this theme to function properly. You can purchase a copy at <a href="http://cart66.com/164.html" target="_blank" title="Purchase Cart66">Cart66.com</a>.</p>
	</div>
<?php
}




/*-----------------------------------------------------------------------------------*/
/* Register Custom Menus
/*-----------------------------------------------------------------------------------*/

add_action('init', 'register_custom_menu');
 
function register_custom_menu() {
	register_nav_menu('header_menu', __('Header Menu'));
	register_nav_menu('footer_menu', __('Footer Menu'));
}




/*-----------------------------------------------------------------------------------*/
/* Register Custom Post Template
/*-----------------------------------------------------------------------------------*/

include("post-templates/post-template.php");




/*-----------------------------------------------------------------------------------*/
/* Load Required Theme Scripts
/*-----------------------------------------------------------------------------------*/

define('THEME', get_bloginfo('template_url'), true);

function sf_theme_js() {
	if (is_admin()) return;
	wp_enqueue_script('jquery');
	wp_enqueue_script('slides', THEME . '/js/slides.js', 'jquery');
	wp_enqueue_script('superfish', THEME . '/js/superfish.js', 'jquery');
	wp_enqueue_script('livetwitter', THEME . '/js/livetwitter.js', 'jquery');
}

add_action('init', sf_theme_js);




/*-----------------------------------------------------------------------------------*/
/* Unregister Default WP Widgets
/*-----------------------------------------------------------------------------------*/

function unregister_default_wp_widgets() {
	unregister_widget('WP_Widget_Calendar');
	unregister_widget('WP_Widget_Archives');
	unregister_widget('WP_Widget_Meta');
	unregister_widget('WP_Widget_Search');
	unregister_widget('WP_Widget_Recent_Posts');
	unregister_widget('WP_Widget_Recent_Comments');
	unregister_widget('WP_Widget_Tag_Cloud');
	unregister_widget('WP_Widget_RSS');
	unregister_widget('WP_Widget_Akismet');
}

add_action('widgets_init', 'unregister_default_wp_widgets', 1);




/*-----------------------------------------------------------------------------------*/
/* Custom Short Title Function
/*-----------------------------------------------------------------------------------*/

function the_short_title($before = '', $after = '', $echo = true, $length = false) {
	$title = get_the_title();
	
	if ( $length && is_numeric($length) ) {
		$title = substr( $title, 0, $length );
	}
	
	if ( strlen($title)> 0 ) {
		$title = apply_filters('the_short_title', $before . $title . $after, $before, $after);
		if ( $echo )
			echo $title;
		else
			return $title;
	}
}




/*-----------------------------------------------------------------------------------*/
/* Add The Blog Page Template
/*-----------------------------------------------------------------------------------*/

if (isset($_GET['activated']) && is_admin()){

	$new_page_title = 'Blog';
	$new_page_content = '';
	$new_page_template = 'page-blog.php'; //ex. template-custom.php. Leave blank if you don't want a custom page template.

	//don't change the code bellow, unless you know what you're doing

	$page_check = get_page_by_title($new_page_title);
	$new_page = array(
		'post_type' => 'page',
		'post_title' => $new_page_title,
		'post_content' => $new_page_content,
		'post_status' => 'publish',
		'post_author' => 1,
	);
	if(!isset($page_check->ID)){
		$new_page_id = wp_insert_post($new_page);
		if(!empty($new_page_template)){
			update_post_meta($new_page_id, '_wp_page_template', $new_page_template);
		}
	}

}




/*-----------------------------------------------------------------------------------*/
/* Custom Excerpt Length
/*-----------------------------------------------------------------------------------*/

function new_excerpt_length($length) {
	return 100;
}
add_filter('excerpt_length', 'new_excerpt_length');

function new_excerpt_more($more) {
	return ' ...';
}
add_filter('excerpt_more', 'new_excerpt_more');




/*-----------------------------------------------------------------------------------*/
/* Custom Breadcrumbs Function
/*-----------------------------------------------------------------------------------*/

function sf_breadcrumbs() {
 
	$delimiter = '&raquo;';
	$name = 'Home'; //text for the 'Home' link
	$currentBefore = '';
	$currentAfter = '';
 
  	if ( !is_home() && !is_front_page() || is_paged() ) {
 
    echo '';
 
    global $post;
    $home = get_bloginfo('url');
    echo '<a href="' . $home . '">' . $name . '</a> ' . $delimiter . ' ';
 
    if ( is_category() ) {
    	global $wp_query;
		$cat_obj = $wp_query->get_queried_object();
		$thisCat = $cat_obj->term_id;
		$thisCat = get_category($thisCat);
		$parentCat = get_category($thisCat->parent);
		if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
		echo $currentBefore . '';
		single_cat_title();
		echo '' . $currentAfter;
 
    } elseif ( is_day() ) {
		echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
		echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
		echo $currentBefore . get_the_time('d') . $currentAfter;
 
    } elseif ( is_month() ) {
		echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
		echo $currentBefore . get_the_time('F') . $currentAfter;
 
    } elseif ( is_year() ) {
		echo $currentBefore . get_the_time('Y') . $currentAfter;
 
    } elseif ( is_single() && !is_attachment() ) {
		$cat = get_the_category(); $cat = $cat[0];
		echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
		echo $currentBefore;
		the_title();
		echo $currentAfter;
 
    } elseif ( is_attachment() ) {
		$parent = get_post($post->post_parent);
		$cat = get_the_category($parent->ID); $cat = $cat[0];
		echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
		echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a> ' . $delimiter . ' ';
		echo $currentBefore;
		the_title();
		echo $currentAfter;
 
    } elseif ( is_page() && !$post->post_parent ) {
		echo $currentBefore;
		the_title();
		echo $currentAfter;
 
    } elseif ( is_page() && $post->post_parent ) {
		$parent_id  = $post->post_parent;
		$breadcrumbs = array();
		while ($parent_id) {
			$page = get_page($parent_id);
			$breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
			$parent_id  = $page->post_parent;
		}
		$breadcrumbs = array_reverse($breadcrumbs);
		foreach ($breadcrumbs as $crumb) echo $crumb . ' ' . $delimiter . ' ';
		echo $currentBefore;
		the_title();
		echo $currentAfter;
 
    } elseif ( is_search() ) {
      	echo $currentBefore . 'Search results for &#39;' . get_search_query() . '&#39;' . $currentAfter;
 
    } elseif ( is_tag() ) {
      	echo $currentBefore . 'Posts tagged &#39;';
      	single_tag_title();
      	echo '&#39;' . $currentAfter;
 
    } elseif ( is_author() ) {
    	global $author;
      	$userdata = get_userdata($author);
      	echo $currentBefore . 'Articles posted by ' . $userdata->display_name . $currentAfter;
 
    } elseif ( is_404() ) {
      	echo $currentBefore . 'Error 404' . $currentAfter;
    }
 
    if ( get_query_var('paged') ) {
      	if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
      	echo __('Page') . ' ' . get_query_var('paged');
      	if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
    }
 
    echo '';
 
  	}
}




/*-----------------------------------------------------------------------------------*/
/* Custom Pagination Function
/*-----------------------------------------------------------------------------------*/

function sf_pagenavi($before = '', $after = '', $prelabel = '', $nxtlabel = '', $pages_to_show = 20, $always_show = false) {
	global $request, $posts_per_page, $wpdb, $paged;
	if(empty($prelabel)) {   $prelabel = 'Previous';
		} if(empty($nxtlabel)) {
		$nxtlabel = 'Next';
	} $half_pages_to_show = round($pages_to_show/2);
	if (!is_single()) {
		if(!is_category()) {
		preg_match('#FROM\s(.*)\sORDER BY#siU', $request, $matches);  } else {
		preg_match('#FROM\s(.*)\sGROUP BY#siU', $request, $matches);  }
		$fromwhere = $matches[1];
		$numposts = $wpdb->get_var("SELECT COUNT(DISTINCT ID) FROM $fromwhere");
		$max_page = ceil($numposts /$posts_per_page);
		if(empty($paged)) {
			$paged = 1;
		}
		if($max_page > 1 || $always_show) {
			echo "$before <div id='paginate'>";
			previous_posts_link($prelabel);
			for($i = $paged - $half_pages_to_show; $i <= $paged + $half_pages_to_show; $i++) {   if ($i >= 1 && $i <= $max_page) {   if($i == $paged) {
					echo ' <a class="current-page" href="'.get_pagenum_link($i).'">'.$i.'</a> ';
						} else {
					echo ' <a href="'.get_pagenum_link($i).'">'.$i.'</a> ';   }
				}
			}
			next_posts_link($nxtlabel, $max_page);
			echo "</div> $after";
		}
	}
}




/*-----------------------------------------------------------------------------------*/
/* Exclude Pages From Search
/*-----------------------------------------------------------------------------------*/

function sf_exclude_pages($query) {
        if ($query->is_search) {
        $query->set('post_type', 'post');
                                }
        return $query;
}
add_filter('pre_get_posts','sf_exclude_pages');




/*-----------------------------------------------------------------------------------*/
/* Unregister Cart66 Plugin Styles
/*-----------------------------------------------------------------------------------*/

add_action( 'wp_print_styles', 'sf_deregister_styles', 100 );

function sf_deregister_styles() {
	wp_deregister_style( 'cart66-css' );
}

add_action('admin_head', 'hide_menus');

function hide_menus() {
	global $current_user;
	get_currentuserinfo();

	If($current_user->user_login = 'admin') {
		?>
		<style>
		   a#content_cart66 {
				display:none;
			}
		</style>
		<?php
	}
}




/*-----------------------------------------------------------------------------------*/
/* Custom Widgets
/*-----------------------------------------------------------------------------------*/

include("widgets/twitter.php");
include("widgets/posts.php");




/*-----------------------------------------------------------------------------------*/
/* Define Some Widgets
/*-----------------------------------------------------------------------------------*/

if ( function_exists('register_sidebar') )
register_sidebar(array('name'=>'1st Column (Left)',
	'before_widget' => '<div id="%1$s" class="widget block %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h3 class="block-heading">',
	'after_title' => '</h3>',
));
register_sidebar(array('name'=>'3rd Column (Right)',
	'before_widget' => '<div id="%1$s" class="widget block %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h3 class="block-heading">',
	'after_title' => '</h3>',
));
?>