<?php

/*-----------------------------------------------------------------------------------*/
/* Get and Then Set the Theme Name
/*-----------------------------------------------------------------------------------*/

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_theme_data(STYLESHEETPATH . '/style.css');
	$themename = $themename['Name'];
	$themename = preg_replace("/\W/", "", strtolower($themename) );
	
	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);
	
	// echo $themename;
}




/*-----------------------------------------------------------------------------------*/
/* Allow Formatting Within Info Boxes
/*-----------------------------------------------------------------------------------*/

function optionscheck_change_santiziation() 
{
	remove_filter( 'of_sanitize_info', 'of_sanitize_allowedtags' );
	add_filter( 'of_sanitize_info', 'sf_of_sanitize_allowedtags' );
}
add_action( 'admin_init','optionscheck_change_santiziation', 100 );




/*-----------------------------------------------------------------------------------*/
/* Define Optional Formatting
/*-----------------------------------------------------------------------------------*/

function sf_of_sanitize_allowedtags( $input ) 
{
	global $allowedtags;
	
	$allowedtags = array(
		'a' => array(
			'href'   => array(),
			'class'  => array(),
			'title'  => array(),
			'target' => array(),
			'rel'    => array()
		),
		'img' => array(
			'src'    => array(),
			'class'  => array(),
			'alt'    => array(),
			'width'  => array(),
			'height' => array()
		),
		'iframe' => array(
			'src'         => array(),
			'height'      => array(),
			'width'       => array(),
			'frameborder' => array()
		),
		'p' => array(
			'id'    => array(),
			'class' => array()
		),
		'bold' => array(
			'id'    => array(),
			'class' => array()
		),
		'ol' => array(
			'id'    => array(),
			'class' => array()
		),
		'li' => array(
			'id'    => array(),
			'class' => array()
		),
		'div' => array(
			'id'    => array(),
			'class' => array()
		),
		'span' => array(
			'id'    => array(),
			'class' => array()
		),
		'br' => array(),
		'strong' => array(),
		'em' => array()
	);
	
	$output = wpautop( wp_kses( $input, $allowedtags ) );
	
	return $output;
}




/*-----------------------------------------------------------------------------------*/
/* Options Framework Styles
/*-----------------------------------------------------------------------------------*/

function sf_optionsframework_styles() { ?>
	
<style type="text/css">
	#optionsframework .note {
	font-style: italic;
	color: #999;
	}
	
	#optionsframework .heading {
	font-size: 14px;
	font-weight: normal;
	}
	
	#optionsframework p {
	margin-top: -5px;
	}
	
	#optionsframework bold {
	font-weight: bold;
	}
	
	#optionsframework .alignleft {
	float: left;
	margin: 0 20px 10px 0;
	}
	
	#optionsframework ol {
	margin: 0 0 10px 0;
	padding: 0;
	}  
	
	#optionsframework ol li {
	list-style: decimal;
	margin: 0 0 0 16px;
	}  
	
	.break {
	width: 100%;
	float: left;
	margin-bottom: 16px;
	}
	
	.last-break {
	width: 100%;
	float: left;
	margin-bottom: 2px;
	}
</style>

<?php
}
add_action( "admin_print_styles-$of_page", 'sf_optionsframework_styles' );




/*-----------------------------------------------------------------------------------*/
/* Define Theme Specific Options
/*-----------------------------------------------------------------------------------*/

function optionsframework_options() {
	
	// Background Defaults
	$theme_background_defaults = array('color' => '', 'image' => '', 'repeat' => '','position' => '','attachment'=>'');
	
	// Categories
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pages
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// Images Path
	$imagepath =  get_stylesheet_directory_uri() . '/images/';
		
	$options = array();
		
	
	
	
	/*-----------------------------------------------------------------------------------*/
	/* Getting Started
	/*-----------------------------------------------------------------------------------*/
	
	$options[] = array( "name" => "Getting Started",
						"type" => "heading");					
						
	$options[] = array( "name" => "Adding Featured Images to Your Posts",
						"desc" => "<p>The <strong>Featured Image</strong> is the image that will be used for each video post thumbnail or standard post thumbnail. The source image you intend to use for your thumbnail should be no smaller than 660px wide by 440px high. To add a featured image to your post, follow the instructions below. If you choose not to add a featured image to your post, the post title will be displayed in its place as shown on the Blocco theme demo.</p>
								   <ol>
								   		<li>Click <strong>Set Featured Image</strong> while editing any post.</li>
								   		<li>Upload or select the image you wish to use within the media options box.</li>
								   		<li>Click <strong>Use As Featured Image</strong> (bottom left) to set the featured image.</li>
								   		<li>Update or publish your post.</li>
								   </ol>",
						"type" => "info");
						
	$options[] = array( "desc" => "<div class='break'></div>",
						"type" => "info");							
						
	$options[] = array( "name" => "Configure Your Custom Menus",
						"desc" => "<p>The Blocco theme has a total of 3 custom menus that are configurable via the <strong>Menus</strong> control panel. The <strong>Social Menu</strong> shown in the Blocco theme demo has already been created for you upon theme activation. To activate the social menu, just follow the intructions below:</p> 
								   <ol>
								   		<li>Click <strong>Menus</strong> under the <strong>Appearance</strong> tab.</li>
								   		<li>Click <strong>Save Menu</strong> (right).</li>
								   		<li>Assign the <strong>Social Menu</strong> to any available location.</li>
								   </ol>",
						"type" => "info");
						
	$options[] = array( "desc" => "<div class='break'></div>",
						"type" => "info");					
						
	$options[] = array( "name" => "Adding Videos to Your Posts",
						"desc" => "<p>You can add YouTube or Vimeo videos to your posts using the Blocco theme as show within the Blocco theme demo. Follow the few simple steps below to add videos to your posts:</p>
								   <ol>
										<li>While editing a post, find the <strong>Post Video Options</strong> box within the sidebar.</li> 
										<li>If you are embedding a video from Vimeo or YouTube, enter the URL to your video within the URL field provided.</li>
										<li>Update or publish your post.</li>
								   </ol>",
						"type" => "info");	
						
	$options[] = array( "desc" => "<div class='last-break'></div>",
						"type" => "info");									
						
						
	
	
	/*-----------------------------------------------------------------------------------*/
	/* Content Options
	/*-----------------------------------------------------------------------------------*/
	
	$options[] = array( "name" => "Theme Options",
						"type" => "heading");							
						
						
						
						
	/*-----------------------------------------------------------------------------------*/
	/* Header Options
	/*-----------------------------------------------------------------------------------*/					
						
	$options[] = array( "name" => "Custom Logo &amp; Favicon Options",
						"desc" => "Use the options below to customize the theme icon (favicon) and logo. You can use a custom logo image or plain text for your logo. The font used for the default Blocco logo is called 'Aventura' and can be found on <a href='http://new.myfonts.com/fonts/sudtipos/aventura/&amp;refby=ca75' title='Aventura' target='_blank'>MyFonts.com</a>.",
						"type" => "info");
	
	$options[] = array( "name" => "Upload a Custom Favicon Image",
						"desc" => "",
						"id" => "icon_image",
						"type" => "upload");								
	
	$options[] = array( "name" => "Upload a Custom Logo Image",
						"desc" => "",
						"id" => "logo_image",
						"type" => "upload");	
						
	$options[] = array( "desc" => "<div class='break'></div>",
						"type" => "info");								
						
						
						
						
	/*-----------------------------------------------------------------------------------*/
	/* Home Page Category
	/*-----------------------------------------------------------------------------------*/					
						
	$options[] = array( "name" => "Home Page Category Options",
						"desc" => "If you would like to replace 'Recent Posts' on the home page with posts from a specified category, first enable and then configure the Home Page Category options below.",
						"type" => "info");
	
	$options[] = array( "name" => "Enable the Home Page Category",
						"desc" => "Click here to enable the 'Home Page Category' option and then configure the options below.",
						"id" => "enable_home_category",
						"type" => "checkbox");
	
	$options[] = array( "name" => "Select the Home Page Category",
						"desc" => "",
						"id" => "home_category",
						"type" => "select",
						"options" => $options_categories);		
						
	$options[] = array( "desc" => "<div class='break'></div>",
						"type" => "info");									
						
						
	
	
	/*-----------------------------------------------------------------------------------*/
	/* Custom Text Options
	/*-----------------------------------------------------------------------------------*/					
						
	$options[] = array( "name" => "Custom Theme Text Options",
						"desc" => "Use the options below to customize theme text elements however you like. You can restore the default options at any time by clicking the 'Restore Defaults' button (bottom left).",
						"type" => "info");
	
	$options[] = array( "name" => "Custom Home Page Menu Text",
						"desc" => "Enter the text you wish to use for the home page menu item in the sidebar.",
						"id" => "home_text",
						"std" => "Home",
						"type" => "text");
	
	$options[] = array( "name" => "Custom Search Field Text",
						"desc" => "Enter the text you wish to use for the search field within the sidebar.",
						"id" => "search_text",
						"std" => "Search for Something",
						"type" => "text");
						
	$options[] = array( "name" => "404 Page Text",
						"desc" => "Enter the text you wish to use for 404 (not found) pages.",
						"id" => "nothing_title_text",
						"std" => "Sorry, Nothing Here by That Name",
						"type" => "text");
						
	$options[] = array( "desc" => "<div class='break'></div>",
						"type" => "info");						
						
						
						
						
	/*-----------------------------------------------------------------------------------*/
	/* Disable Enable Options
	/*-----------------------------------------------------------------------------------*/						
						
	$options[] = array( "name" => "Disable Theme Features and/or Information",
						"desc" => "Use the options below to disable or hide certain theme features and information such as mobile optimizations the post thumbnail grid lines, the post info box and miscellaneous post information.",
						"type" => "info");
						
	$options[] = array( "name" => "Disable Theme Features",
	   					"desc" => "",
	   					"id" => "disable_theme_features",
	   					"type" => "multicheck",
	   					"options" => array ( '1' => 'Disable Search Field', '2' => 'Disable Logo', '3' => 'Disable iPhone Optimizations', '4' => 'Disable iPad Optimizations' ));					
						
	$options[] = array( "name" => "Disable Post Features",
	   					"desc" => "",
	   					"id" => "disable_post_features",
	   					"type" => "multicheck",
	   					"options" => array ( '1' => 'Disable Post Thumbnail Grid Lines', '2' => 'Disable Post Comments' ));					
								  					
	$options[] = array( "name" => "Disable or Hide Post Info",
	   					"desc" => "",
	   					"id" => "disable_post_info",
	   					"type" => "multicheck",
	   					"options" => array ( '1' => 'Disable the Post Info Box', '2' => 'Hide the Post Author', '3' => 'Hide the Post Date', '4' => 'Hide the Post Categories', '5' => 'Hide the Post Comments Number' )); 
    
    $options[] = array( "desc" => "<div class='last-break'></div>",
    					"type" => "info");					
    					
    																								
	
	
	return $options;
}