<?php

/*-----------------------------------------------------------------------------------*/
/* Options Framework Functions
/*-----------------------------------------------------------------------------------*/

if ( STYLESHEETPATH == TEMPLATEPATH ) {
	define('OF_FILEPATH', TEMPLATEPATH);
	define('OF_DIRECTORY', get_bloginfo('template_directory'));
} else {
	define('OF_FILEPATH', STYLESHEETPATH);
	define('OF_DIRECTORY', get_bloginfo('stylesheet_directory'));
}

require_once (OF_FILEPATH . '/admin/admin-functions.php');
require_once (OF_FILEPATH . '/admin/admin-interface.php');
require_once (OF_FILEPATH . '/admin/theme-options.php');
require_once (OF_FILEPATH . '/admin/theme-functions.php');




/*-----------------------------------------------------------------------------------*/
/* Load Required Theme Scripts
/*-----------------------------------------------------------------------------------*/

define('THEME', get_bloginfo('template_url'), true);

function sf_theme_js() {
	if (is_admin()) return;
	wp_enqueue_script('jquery');
	wp_enqueue_script('superfish', THEME . '/js/superfish.min.js', 'jquery');
	wp_enqueue_script('poshytip', THEME . '/js/poshytip.min.js', 'jquery');
	wp_enqueue_script('carousel', THEME . '/js/carousel.min.js', 'jquery');
	wp_enqueue_script('easing', THEME . '/js/easing.min.js', 'jquery');
	wp_enqueue_style('fancybox', THEME . '/js/fancybox/style.css');
	wp_enqueue_script('fancybox', THEME . '/js/fancybox/fancybox.min.js', 'jquery');
	
}
add_action('init', sf_theme_js);




/*-----------------------------------------------------------------------------------*/
/* Post Thumbnails
/*-----------------------------------------------------------------------------------*/

if (function_exists('add_theme_support')) {
    add_theme_support('post-thumbnails');
    set_post_thumbnail_size(300, 200, true);
}




/*-----------------------------------------------------------------------------------*/
/*	Post Meta (Images and Video Options)
/*-----------------------------------------------------------------------------------*/

include("post-meta.php");




/*-----------------------------------------------------------------------------------*/
/*	Hide Unused Admin Items
/*-----------------------------------------------------------------------------------*/

add_action('admin_head', 'hide_menus');

function hide_menus() {
	global $current_user;
	get_currentuserinfo();

	if($current_user->user_login = 'admin') {
		?>
		<style>
		#revisionsdiv,
		#editor-toolbar,
		#ed_toolbar,
		#quicktags,
		#editorcontainer,
		#post-status-info,
		#commentsdiv,
		#commentstatusdiv,
		#postcustom,
		#tagsdiv-post_tag,
		#contextual-help-link-wrap {
		display:none;
		}
		</style>
		<?php
	}
}

function remove_menus () {
global $menu;
	$restricted = array(__('Links'), __('Pages'), __('Comments'), __('Widgets'));
	end ($menu);
	while (prev($menu)){
		$value = explode(' ',$menu[key($menu)][0]);
		if(in_array($value[0] != NULL?$value[0]:"" , $restricted)){unset($menu[key($menu)]);}
	}
}
add_action('admin_menu', 'remove_menus');

function remove_submenus() {
  global $submenu;
    unset($submenu['options-general.php'][25]);     
}
add_action('admin_menu', 'remove_submenus');




/*-----------------------------------------------------------------------------------*/
/*	Custom Excerpt Function
/*-----------------------------------------------------------------------------------*/

function new_excerpt_length($length) {
	return 50;
}
add_filter('excerpt_length', 'new_excerpt_length');

function new_excerpt_more($more) {
	return ' ...';
}
add_filter('excerpt_more', 'new_excerpt_more');




/*-----------------------------------------------------------------------------------*/
/* Custom Video Function
/*-----------------------------------------------------------------------------------*/

function sf_video($postid) {
	
	$video_url = get_post_meta($postid, 'sf_video_url', true);
	$width = get_post_meta($postid, 'sf_video_width', true);
	$height = get_post_meta($postid, 'sf_video_height', true);
	$embeded_code = get_post_meta($postid, 'sf_embed_code', true);
	
	if($width == '')
		$width = 600;
	
	if($height == '')
		$height = 400;

	if(trim($embeded_code) == '') 
	{
		
		if(preg_match('/youtube/', $video_url)) 
		{
			
			if(preg_match('/[\\?\\&]v=([^\\?\\&]+)/', $video_url, $matches))
			{
				$output = '<iframe title="YouTube video player" class="youtube-player" type="text/html" width="'.$width.'" height="'.$height.'" src="http://www.youtube.com/embed/'.$matches[1].'" frameborder="0" allowFullScreen></iframe>';
			}
			else 
			{
				$output = __('Sorry that seems to be an invalid <strong>YouTube</strong> URL. Please check it again.', 'framework');
			}
			
		}
		elseif(preg_match('/vimeo/', $video_url)) 
		{
			
			if(preg_match('~^http://(?:www\.)?vimeo\.com/(?:clip:)?(\d+)~', $video_url, $matches))
			{
				$output = '<iframe src="http://player.vimeo.com/video/'.$matches[1].'" width="'.$width.'" height="'.$height.'" frameborder="0"></iframe>';
			}
			else 
			{
				$output = __('Sorry that seems to be an invalid <strong>Vimeo</strong> URL. Please check it again. Make sure there is a string of numbers at the end.', 'framework');
			}
			
		}
		else 
		{
			$output = __('Sorry that is an invalid YouTube or Vimeo URL.', 'framework');
		}
		
		echo $output;
		
	}
	else
	{
		echo stripslashes(htmlspecialchars_decode($embeded_code));
	}
	
}

?>