<?php
/*
Plugin Name: Superior Recent Comments
Plugin URI: http://jameslao.com/
Description: Adds a better recent comments widget. Based on the plugin by George Notaras.
Author: James Lao
Version: 1.0
Author URI: http://jameslao.com/

Notes: Custom HTML for Massive News.
*/

define('P75_SRC_OPTION_KEY', 'p75_recent_comments');
define('P75_SRC_ID_BASE', 'p75-recent-comments');

// Displays widget on blag
// $widget_args: number
//    number: which of the several widgets of this type do we mean

function p75_recent_comments_widget( $args, $widget_args = 1 ) {
	global $wpdb;
	
	extract( $args, EXTR_SKIP );
	if ( is_numeric($widget_args) )
		$widget_args = array( 'number' => $widget_args );
	$widget_args = wp_parse_args( $widget_args, array( 'number' => -1 ) );
	extract( $widget_args, EXTR_SKIP );
	
	// Data should be stored as array:  array( number => data for that instance of the widget, ... )
	$options = get_option(P75_SRC_OPTION_KEY);
	if ( !isset($options[$number]) )
		return;
	
	$sql = "SELECT DISTINCT ID, post_title, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, 
		SUBSTRING(comment_content,1,".$options[$number]['excerpt_len'].") AS com_excerpt 
		FROM $wpdb->comments 
		LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID = $wpdb->posts.ID) 
		WHERE comment_approved = '1' AND comment_type = '' AND post_password = '' 
		ORDER BY comment_date_gmt DESC 
		LIMIT ".$options[$number]['num_comments'];
	$comments = $wpdb->get_results($sql);

	echo $before_widget;
	if ( !$options[$number]['title'] )
		$options[$number]['title'] = 'Recent Comments';

	echo $before_title . $options[$number]['title'] . $after_title;

	echo "<ul>\n";
	foreach ($comments as $comment) {
		echo "\n\t<li id='recent-comment-".$comment->comment_ID."' class='recent_comment'><a href=\"" . get_permalink($comment->ID) . "#comment-" . $comment->comment_ID  . "\" title=\"on " . $comment->post_title . "\">" . $comment->comment_author . "</a>: " . strip_tags($comment->com_excerpt) . "...</li>\n";
	}
	echo "</ul>\n";
	
	echo $after_widget;
}

// Displays form for a particular instance of the widget.  Also updates the data after a POST submit
// $widget_args: number
//    number: which of the several widgets of this type do we mean
function p75_recent_comments_control( $widget_args = 1 ) {
	global $wp_registered_widgets;
	static $updated = false; // Whether or not we have already updated the data after a POST submit

	if ( is_numeric($widget_args) )
		$widget_args = array( 'number' => $widget_args );
	$widget_args = wp_parse_args( $widget_args, array( 'number' => -1 ) );
	extract( $widget_args, EXTR_SKIP );

	// Data should be stored as array:  array( number => data for that instance of the widget, ... )
	$options = get_option(P75_SRC_OPTION_KEY);
	if ( !is_array($options) )
		$options = array();

	// We need to update the data
	if ( !$updated && !empty($_POST['sidebar']) ) {
		// Tells us what sidebar to put the data in
		$sidebar = (string) $_POST['sidebar'];

		$sidebars_widgets = wp_get_sidebars_widgets();
		if ( isset($sidebars_widgets[$sidebar]) )
			$this_sidebar =& $sidebars_widgets[$sidebar];
		else
			$this_sidebar = array();

		foreach ( $this_sidebar as $_widget_id ) {
			// Remove all widgets of this type from the sidebar.  We'll add the new data in a second.  This makes sure we don't get any duplicate data
			// since widget ids aren't necessarily persistent across multiple updates
			if ( 'p75_recent_comments_widget' == $wp_registered_widgets[$_widget_id]['callback'] && isset($wp_registered_widgets[$_widget_id]['params'][0]['number']) ) {
				$widget_number = $wp_registered_widgets[$_widget_id]['params'][0]['number'];
				if ( !in_array( P75_SRC_ID_BASE . "-$widget_number", $_POST['widget-id'] ) ) // the widget has been removed. "many-$widget_number" is "{id_base}-{widget_number}
					unset($options[$widget_number]);
			}
		}
		
		foreach ( (array) $_POST[P75_SRC_ID_BASE] as $widget_number => $src_instance )
		{
			// compile data from $widget_many_instance
			$options[$widget_number] =
				array
				(
					'title' => wp_specialchars( $src_instance['title'] ),
					'num_comments' => $src_instance['num_comments'],
					'excerpt_len' => $src_instance['excerpt_len']
				);
		}
		
		update_option('p75_recent_comments', $options);
		
		$updated = true; // So that we don't go through this more than once
	}
	
	
	// Here we echo out the form
	if ( -1 == $number ) { // We echo out a template for a form which can be converted to a specific form later via JS
		$number = '%i%';
		$title = "";
		$num_comments = 5;
		$excerpt_len = 60;
	} else {
		$title = attribute_escape($options[$number]['title']);
		$num_comments = $options[$number]['num_comments'];
		$excerpt_len = $options[$number]['excerpt_len'];
	}

	// The form has inputs with names like widget-many[$number][something] so that all data for that instance of
	// the widget are stored in one $_POST variable: $_POST['widget-many'][$number]
?>
		<p>
			<label for="<?php echo P75_SRC_ID_BASE."-title-$number"; ?>">
				<?php _e( 'Title' ); ?>:
				<input class="widefat" id="<?php echo P75_SRC_ID_BASE."-title-".$number; ?>" name="<?php echo P75_SRC_ID_BASE."[$number][title]"; ?>" type="text" value="<?php echo $title; ?>" />
			</label>
		</p>
		<p>
			<label for="<?php echo P75_SRC_ID_BASE."-num-".$number; ?>">
				<?php _e('Number of comments to show'); ?>:
				<input id="<?php echo P75_SRC_ID_BASE."-num-".$number; ?>" style="text-align: center;" name="<?php echo P75_SRC_ID_BASE."[$number][num_comments]"; ?>" type="text" value="<?php echo $num_comments; ?>" size='3' />
			</label>
		</p>
		<p>
			<label for="<?php echo P75_SRC_ID_BASE."-excerpt-len-".$number; ?>">
				<?php _e('Excerpt length'); ?>:
				<input id="<?php echo P75_SRC_ID_BASE."-excerpt-len-".$number; ?>" style="text-align: center;" name="<?php echo P75_SRC_ID_BASE."[$number][excerpt_len]"; ?>" type="text" value="<?php echo $excerpt_len; ?>" size='3' />
			</label>
		</p>
		<input type="hidden" id="<?php echo P75_SRC_ID_BASE."-submit-$number"; ?>" name="<?php echo P75_SRC_ID_BASE."[$number][submit]"; ?>" value="1" />

<?php

}

// Registers each instance of our widget on startup
function p75_recent_comments_register() {
	if ( !$options = get_option(P75_SRC_OPTION_KEY) )
		$options = array();

	$widget_ops = array('classname' => 'p75_recent_comments', 'description' => __('A recent comments widget with comment excerpt.'));
	$control_ops = array('id_base' => P75_SRC_ID_BASE );
	$name = __('Superior Recent Comments');

	$registered = false;
	foreach ( array_keys($options) as $o ) {
		// Old widgets can have null values for some reason
		if ( !isset($options[$o]['title']) ) // we used 'something' above in our exampple.  Replace with with whatever your real data are.
			continue;

		// $id should look like {$id_base}-{$o}
		$id = P75_SRC_ID_BASE . "-$o"; // Never never never translate an id
		$registered = true;
		wp_register_sidebar_widget( $id, $name, 'p75_recent_comments_widget', $widget_ops, array( 'number' => $o ) );
		wp_register_widget_control( $id, $name, 'p75_recent_comments_control', $control_ops, array( 'number' => $o ) );
	}

	// If there are none, we register the widget's existance with a generic template
	if ( !$registered ) {
		wp_register_sidebar_widget( P75_SRC_ID_BASE . '-1', $name, 'p75_recent_comments_widget', $widget_ops, array( 'number' => -1 ) );
		wp_register_widget_control( P75_SRC_ID_BASE . '-1', $name, 'p75_recent_comments_control', $control_ops, array( 'number' => -1 ) );
	}
}

// This is important
add_action( 'widgets_init', 'p75_recent_comments_register' );

?>
