<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_theme_data(STYLESHEETPATH . '/style.css');
	$themename = $themename['Name'];
	$themename = preg_replace("/\W/", "", strtolower($themename) );

	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);

	// echo $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {

	// Test data
	$test_array = array("one" => __("One", 'organicthemes'),"two" => __("Two", 'organicthemes'),"three" => __("Three", 'organicthemes'),"four" => __("Four", 'organicthemes'),"five" => __("Five", 'organicthemes'));

	// Multicheck Array
	$multicheck_array = array("one" => __("French Toast", 'organicthemes'), "two" => __("Pancake", 'organicthemes'), "three" => __("Omelette", 'organicthemes'), "four" => __("Crepe", 'organicthemes'), "five" => __("Waffle", 'organicthemes'));

	// Multicheck Defaults
	$multicheck_defaults = array("one" => "true","five" => "true");

	// Background Defaults
	$background_defaults = array('color' => '', 'image' => '', 'repeat' => 'repeat','position' => 'top center','attachment'=>'scroll');
	
	// Slider Transition Array
	$transition_array = array("1000" => __("1 Second", 'organicthemes'), "2000" => __("2 Seconds", 'organicthemes'), "4000" => __("4 Seconds", 'organicthemes'), "6000" => __("6 Seconds", 'organicthemes'), "8000" => __("8 Seconds", 'organicthemes'), "10000" => __("10 Seconds", 'organicthemes'), "12000" => __("12 Seconds", 'organicthemes'), "14000" => __("14 Seconds", 'organicthemes'), "16000" => __("16 Seconds", 'organicthemes'), "18000" => __("18 Seconds", 'organicthemes'), "20000" => __("20 Seconds", 'organicthemes'), "30000" => __("30 Seconds", 'organicthemes'), "60000" => __("1 Minute", 'organicthemes'), "999999999" => __("Hold Frame", 'organicthemes'));
	
	// Yes or No Array
	$yesno_array = array("true" => __("Yes", 'organicthemes'), "false" => __("No", 'organicthemes'));
	
	// Stylesheet Array
	$stylesheet_array = array("true" => __("White", 'organicthemes'), "false" => __("Black", 'organicthemes'));
	
	// Pull product categories into an array
	$args = array( 'hide_empty' => '0' );
	$options_product = array();
	$options_product_obj = get_terms('product_cat', $args);
	if( $options_product_obj ) {
	    foreach( $options_product_obj as $_product ) {
	        $options_product[$_product->slug] = $_product->name;
	    }
	}
	
	array_unshift( $options_product, 'All Categories' );

	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Add all categories option
    $options_categories[0] = __("All Categories", 'organicthemes');

	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages['false'] = __("Select a page:", 'organicthemes');
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_bloginfo('stylesheet_directory') . '/images/';

	$options = array();
	
	$options[] = array( "name" => __("Header", 'organicthemes'),
						"type" => "heading");
						
		$options[] = array( "name" => __("Menu Cart Link", 'organicthemes'),
							"desc" => __("Enter the link to your shopping cart.", 'organicthemes'),
							"id" => "cart_link",
							"std" => "/cart/", 'organicthemes',
							"type" => "text");
						
		$options[] = array( "name" => __("Display Social Buttons?", 'organicthemes'),
							"desc" => __("Select whether or not you would like to display the Tweet, Facebook Like and Google Plus buttons in the header.", 'organicthemes'),
							"id" => "display_socialheader",
							"std" => "1",
							"type" => "checkbox");
							
		$options[] = array( "name" => __("Display The Search Field?", 'organicthemes'),
							"desc" => __("Select whether or not you would like to display the search field in the header.", 'organicthemes'),
							"id" => "display_search",
							"std" => "1",
							"type" => "checkbox");
	
	$options[] = array( "name" => __("Slideshow", 'organicthemes'),
						"type" => "heading");
						
		$options[] = array( "name" => __("Display Product Slider?", 'organicthemes'),
							"desc" => __("Select whether or not you would like to display the product slider on the homepage.", 'organicthemes'),
							"id" => "display_slider",
							"std" => "1",
							"type" => "checkbox");
							
		$options[] = array( "name" => __("Display Product Title?", 'organicthemes'),
							"desc" => __("Select whether or not you would like to display the product title within the slider.", 'organicthemes'),
							"id" => "display_title",
							"std" => "1",
							"type" => "checkbox");
							
		$options[] = array( "name" => __("Product Slider Category", 'organicthemes'),
							"desc" => __("Choose the product category you wish to display in the homepage featured slider.", 'organicthemes'),
							"id" => "category_slider",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_product);
							
		$options[] = array( "name" => __("Product Slider Posts To Display", 'organicthemes'),
							"desc" => __("Enter the number of products you would like to display in the homepage featured slider.", 'organicthemes'),
							"id" => "postnumber_slider",
							"std" => "10",
							"type" => "text");
							
		$options[] = array( "name" => __("Product Slider Transition Interval", 'organicthemes'),
							"desc" => __("Choose the transition time for the homepage featured slider. This is the time the frame is held before transitioning to the next slide.", 'organicthemes'),
							"id" => "slider_transition_interval",
							"std" => "10000",
							"type" => "select",
							"options" => $transition_array);

	$options[] = array( "name" => __("Homepage", 'organicthemes'),
						"type" => "heading");
						
		$options[] = array( "name" => __("Display Featured Prodcuts?", 'organicthemes'),
							"desc" => __("Select whether or not you would like to display the featured products beneath the slider.", 'organicthemes'),
							"id" => "display_products_lg",
							"std" => "1",
							"type" => "checkbox");								
						
		$options[] = array( "name" => __("Featured Products Category", 'organicthemes'),
							"desc" => __("Choose the product category you wish to display for the large featured products beneath the slider.", 'organicthemes'),
							"id" => "category_products_lg",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_product);
							
		$options[] = array( "name" => __("Featured Products Displayed", 'organicthemes'),
							"desc" => __("Enter the number of large featured products you would like displayed beneath the slider.", 'organicthemes'),
							"id" => "postnumber_products_lg",
							"std" => "4",
							"type" => "text");
							
		$options[] = array( "name" => __("Display Four Column Prodcuts?", 'organicthemes'),
							"desc" => __("Select whether or not you would like to display the four columns of products on the homepage.", 'organicthemes'),
							"id" => "display_products_sm",
							"std" => "1",
							"type" => "checkbox");
							
		$options[] = array( "name" => __("First Column Products Category", 'organicthemes'),
							"desc" => __("Choose the product category you wish to display in the first column.", 'organicthemes'),
							"id" => "category_products_sm1",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_product);
							
		$options[] = array( "name" => __("First Column Products Displayed", 'organicthemes'),
							"desc" => __("Enter the number of products you would like displayed in the first column.", 'organicthemes'),
							"id" => "postnumber_products_sm1",
							"std" => "3",
							"type" => "text");
							
		$options[] = array( "name" => __("Second Column Products Category", 'organicthemes'),
							"desc" => __("Choose the product category you wish to display in the second column.", 'organicthemes'),
							"id" => "category_products_sm2",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_product);
							
		$options[] = array( "name" => __("Second Column Products Displayed", 'organicthemes'),
							"desc" => __("Enter the number of products you would like displayed in the second column.", 'organicthemes'),
							"id" => "postnumber_products_sm2",
							"std" => "3",
							"type" => "text");
							
		$options[] = array( "name" => __("Third Column Products Category", 'organicthemes'),
							"desc" => __("Choose the product category you wish to display in the third column.", 'organicthemes'),
							"id" => "category_products_sm3",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_product);
							
		$options[] = array( "name" => __("Third Column Products Displayed", 'organicthemes'),
							"desc" => __("Enter the number of products you would like displayed in the third column.", 'organicthemes'),
							"id" => "postnumber_products_sm3",
							"std" => "3",
							"type" => "text");
							
		$options[] = array( "name" => __("Fourth Column Products Category", 'organicthemes'),
							"desc" => __("Choose the product category you wish to display in the fourth column.", 'organicthemes'),
							"id" => "category_products_sm4",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_product);
							
		$options[] = array( "name" => __("Fourth Column Products Displayed", 'organicthemes'),
							"desc" => __("Enter the number of products you would like displayed in the fourth column.", 'organicthemes'),
							"id" => "postnumber_products_sm4",
							"std" => "3",
							"type" => "text");
						
	$options[] = array( "name" => __("Page Templates", 'organicthemes'),
						"type" => "heading");
						
		$options[] = array( "name" => __("Blog Template Category", 'organicthemes'),
							"desc" => __("Choose the category you wish to display on the blog page template.", 'organicthemes'),
							"id" => "category_blog",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_categories);
									
		$options[] = array( "name" => __("Blog Posts To Display", 'organicthemes'),
							"desc" => __("Enter the number of posts you would like to display on the blog page template.", 'organicthemes'),
							"id" => "postnumber_blog",
							"std" => "5",
							"type" => "text");
							
		$options[] = array( "name" => __("Full Width Shop Page Category", 'organicthemes'),
							"desc" => __("Choose the product category you wish to display in the full width shop page template.", 'organicthemes'),
							"id" => "category_products_page1",
							"std" => __("Select a category:", 'organicthemes'),
							"type" => "select",
							"options" => $options_product);
							
		$options[] = array( "name" => __("Full Width Shop Page Products Displayed", 'organicthemes'),
							"desc" => __("Enter the number of products you would like displayed in the full width shop page template.", 'organicthemes'),
							"id" => "postnumber_products_page1",
							"std" => "24",
							"type" => "text");
						
	$options[] = array( "name" => __("Colors", 'organicthemes'),
						"type" => "heading");
						
		$options[] = array( "name" => __("Menu Background Color", 'organicthemes'),
							"desc" => __("Select the color you wish to use for the main menu background color.", 'organicthemes'),
							"id" => "menu_color",
							"std" => "#669900",
							"type" => "color");
							
		$options[] = array( "name" => __("SubMenu Hover Color", 'organicthemes'),
							"desc" => __("Select the color you wish to use for the submenu background hover color.", 'organicthemes'),
							"id" => "submenu_hover",
							"std" => "#336600",
							"type" => "color");
												
		$options[] = array( "name" => __("Link Color", 'organicthemes'),
							"desc" => __("Select the color you wish to use for the link colors.", 'organicthemes'),
							"id" => "link_color",
							"std" => "#151515",
							"type" => "color");
							
		$options[] = array( "name" => __("Link Hover Color", 'organicthemes'),
							"desc" => __("Select the color you wish to use for the text link hover colors.", 'organicthemes'),
							"id" => "link_hover_color",
							"std" => "#669900",
							"type" => "color");
							
		$options[] = array( "name" => __("Button Background Color", 'organicthemes'),
							"desc" => __("Select the link background color for buttons.", 'organicthemes'),
							"id" => "link_background_color",
							"std" => "#669900",
							"type" => "color");	
							
		$options[] = array( "name" => __("Button Background Hover Color", 'organicthemes'),
							"desc" => __("Select the background hover color for buttons.", 'organicthemes'),
							"id" => "link_background_hover_color",
							"std" => "#336600",
							"type" => "color");

	return $options;
}