<?php

/*-----------------------------------------------------------------------------------*/
/* Options Framework Functions
/*-----------------------------------------------------------------------------------*/

if ( STYLESHEETPATH == TEMPLATEPATH ) {
	define('OF_FILEPATH', TEMPLATEPATH);
	define('OF_DIRECTORY', get_bloginfo('template_directory'));
} else {
	define('OF_FILEPATH', STYLESHEETPATH);
	define('OF_DIRECTORY', get_bloginfo('stylesheet_directory'));
}

require_once (OF_FILEPATH . '/admin/admin-functions.php');
require_once (OF_FILEPATH . '/admin/admin-interface.php');
require_once (OF_FILEPATH . '/admin/theme-options.php');
require_once (OF_FILEPATH . '/admin/theme-functions.php');




/*-----------------------------------------------------------------------------------*/
/* Check for Gravity Forms
/*-----------------------------------------------------------------------------------*/

gravity_check();

function gravity_check()
{
	if ( !function_exists("gravity_form") )
	{
		add_action('admin_notices', 'gravity_check_notice');
	}
}

// The admin notice.
function gravity_check_notice()
{
?>
	<div class='updated fade'>
		<p>The Gravity Forms plugin is required for this theme to function properly. You can purchase a copy at <a href="http://press75.com/go/gravity/" target="_blank" title="Purchase Gravity Forms">GravityForms.com</a>.</p>
	</div>
<?php
}




/*-----------------------------------------------------------------------------------*/
/* Add The Post Form Page
/*-----------------------------------------------------------------------------------*/

if (isset($_GET['activated']) && is_admin()){

	$new_page_title = 'Post Something';
	$new_page_content = 'You will want to insert your post form here... If you would like to use the sample form as shown on the Posted theme demo, just import the "posted-form.xml" file within the Gravity Forms import/export utilility. After you have done so, just click the "Add Gravity Form" icon above to insert your form within this page.';
	$new_page_template = '';

	//don't change the code bellow, unless you know what you're doing

	$page_check = get_page_by_title($new_page_title);
	$new_page = array(
		'post_type' => 'page',
		'post_title' => $new_page_title,
		'post_content' => $new_page_content,
		'post_status' => 'publish',
		'post_author' => 1,
	);
	if(!isset($page_check->ID)){
		$new_page_id = wp_insert_post($new_page);
		if(!empty($new_page_template)){
			update_post_meta($new_page_id, '_wp_page_template', $new_page_template);
		}
	}

}




/*-----------------------------------------------------------------------------------*/
/* Add The Post Confirmation Page
/*-----------------------------------------------------------------------------------*/

if (isset($_GET['activated']) && is_admin()){

	$new_page_title = 'Post Confirmation';
	$new_page_content = 'Thank you very much for submitting your post. Your information will be reviewed and published as soon as possible as long as everything checks out. This is just an example of a confirmation page for submitted posts. You can update and select this page within the "Form Settings" (Confirmation Tab).';
	$new_page_template = '';

	//don't change the code bellow, unless you know what you're doing

	$page_check = get_page_by_title($new_page_title);
	$new_page = array(
		'post_type' => 'page',
		'post_title' => $new_page_title,
		'post_content' => $new_page_content,
		'post_status' => 'publish',
		'post_author' => 1,
	);
	if(!isset($page_check->ID)){
		$new_page_id = wp_insert_post($new_page);
		if(!empty($new_page_template)){
			update_post_meta($new_page_id, '_wp_page_template', $new_page_template);
		}
	}

}




/*-----------------------------------------------------------------------------------*/
/* Register Custom Menus
/*-----------------------------------------------------------------------------------*/

add_action('init', 'register_custom_menu');
 
function register_custom_menu() {
register_nav_menu('main_menu', __('Main Menu'));
}




/*-----------------------------------------------------------------------------------*/
/* Load Required Theme Scripts
/*-----------------------------------------------------------------------------------*/

define('THEME', get_bloginfo('template_url'), true);

function sf_theme_js() {
	if (is_admin()) return;
	wp_enqueue_script('jquery');
	wp_enqueue_script('easing', THEME . '/js/jquery.easing.min.js', 'jquery');
	
	if (get_option('of_disable_fancy') == 'false') {
		wp_enqueue_style('fancybox', THEME . '/js/fancybox/style.css');
		wp_enqueue_script('fancybox', THEME . '/js/fancybox/fancybox.min.js', 'jquery');
	}
}
add_action('init', sf_theme_js);




/*-----------------------------------------------------------------------------------*/
/* Load Custom Widgets
/*-----------------------------------------------------------------------------------*/

include("widgets/125x125.php");




/*-----------------------------------------------------------------------------------*/
/* Custom Excerpt Length
/*-----------------------------------------------------------------------------------*/

function new_excerpt_length($length) {
	return 100;
}
add_filter('excerpt_length', 'new_excerpt_length');

function new_excerpt_more($more) {
	return ' ...';
}
add_filter('excerpt_more', 'new_excerpt_more');




/*-----------------------------------------------------------------------------------*/
/* Custom Tag Pagination
/*-----------------------------------------------------------------------------------*/

function sf_tagnavi($before = '', $after = '', $prelabel = '', $nxtlabel = '', $pages_to_show = 20, $always_show = false) {
	global $request, $posts_per_page, $wpdb, $paged;
	if(empty($prelabel)) {   $prelabel = 'Previous';
		} if(empty($nxtlabel)) {
		$nxtlabel = 'Next';
	} $half_pages_to_show = round($pages_to_show/2);
	if (!is_single()) {
		if(!is_tag()) {
			preg_match('#FROM\s(.*)\sORDER BY#siU', $request, $matches);  
		} else {
			preg_match('#FROM\s(.*)\sGROUP BY#siU', $request, $matches);  }
			$fromwhere = $matches[1];
			$numposts = $wpdb->get_var("SELECT COUNT(DISTINCT ID) FROM $fromwhere");
			$max_page = ceil($numposts /$posts_per_page);
			if(empty($paged)) {
				$paged = 1;
		}
		if($max_page > 1 || $always_show) {
			echo "$before <div id='pagination' class='row line'>";
			previous_posts_link($prelabel);
			for($i = $paged - $half_pages_to_show; $i <= $paged + $half_pages_to_show; $i++) {   if ($i >= 1 && $i <= $max_page) {   if($i == $paged) {
					echo ' <a class="current-page" href="'.get_pagenum_link($i).'">'.$i.'</a> ';
						} else {
					echo ' <a href="'.get_pagenum_link($i).'">'.$i.'</a> ';   }
				}
			}
			next_posts_link($nxtlabel, $max_page);
			echo "</div> $after";
		}
	}
}




/*-----------------------------------------------------------------------------------*/
/* Custom Category Pagination
/*-----------------------------------------------------------------------------------*/

function sf_catnavi($before = '', $after = '', $prelabel = '', $nxtlabel = '', $pages_to_show = 20, $always_show = false) {
	global $request, $posts_per_page, $wpdb, $paged;
	if(empty($prelabel)) {   $prelabel = 'Previous';
		} if(empty($nxtlabel)) {
		$nxtlabel = 'Next';
	} $half_pages_to_show = round($pages_to_show/2);
	if (!is_single()) {
		if(!is_category()) {
			preg_match('#FROM\s(.*)\sORDER BY#siU', $request, $matches);  
		} else {
			preg_match('#FROM\s(.*)\sGROUP BY#siU', $request, $matches);  }
			$fromwhere = $matches[1];
			$numposts = $wpdb->get_var("SELECT COUNT(DISTINCT ID) FROM $fromwhere");
			$max_page = ceil($numposts /$posts_per_page);
			if(empty($paged)) {
				$paged = 1;
		}
		if($max_page > 1 || $always_show) {
			echo "$before <div id='pagination' class='row line'>";
			previous_posts_link($prelabel);
			for($i = $paged - $half_pages_to_show; $i <= $paged + $half_pages_to_show; $i++) {   if ($i >= 1 && $i <= $max_page) {   if($i == $paged) {
					echo ' <a class="current-page" href="'.get_pagenum_link($i).'">'.$i.'</a> ';
						} else {
					echo ' <a href="'.get_pagenum_link($i).'">'.$i.'</a> ';   }
				}
			}
			next_posts_link($nxtlabel, $max_page);
			echo "</div> $after";
		}
	}
}




/*-----------------------------------------------------------------------------------*/
/* Exclude Pages From Search
/*-----------------------------------------------------------------------------------*/

function sf_exclude_pages($query) {
        if ($query->is_search) {
        $query->set('post_type', 'post');
                                }
        return $query;
}
add_filter('pre_get_posts','sf_exclude_pages');




/*-----------------------------------------------------------------------------------*/
/* Unregister Non-Compatible Widgets
/*-----------------------------------------------------------------------------------*/

function unregister_default_wp_widgets() {
	unregister_widget('WP_Widget_Pages');
	unregister_widget('WP_Widget_Calendar');
	unregister_widget('WP_Widget_Archives');
	unregister_widget('WP_Widget_Links');
	unregister_widget('WP_Widget_Meta');
	unregister_widget('WP_Widget_Search');
	unregister_widget('WP_Widget_Categories');
	unregister_widget('WP_Widget_Recent_Posts');
	unregister_widget('WP_Widget_Recent_Comments');
	unregister_widget('WP_Widget_Tag_Cloud');
	unregister_widget('WP_Widget_RSS');
	unregister_widget('WP_Widget_Text');
	unregister_widget('WP_Widget_Akismet');
	unregister_widget('WP_Nav_Menu_Widget');
	unregister_widget( 'GFWidget' );
}
 
add_action('widgets_init', 'unregister_default_wp_widgets', 11);
    




/*-----------------------------------------------------------------------------------*/
/* Define Some Widgets
/*-----------------------------------------------------------------------------------*/

if (get_option('of_sidebar_ads') == 'true') {
	if ( function_exists('register_sidebar') )
	register_sidebar(array('name'=>'Advertisements',
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '',
		'after_title' => '',
	));
}

?>