<?php
/*
Plugin Name: Featurd Content Widget
Plugin URI: http://jameslao.com/
Description: Adds a widget that can display a specified number of posts from a single category. Can also set how many widgets to show.
Author: James Lao	
Version: 2.0
Author URI: http://jameslao.com/
*/

class CategoryPostsWidget extends WP_Widget {

function CategoryPostsWidget() {
	parent::WP_Widget(false, $name='Featurd Content');
}

/**
 * Displays Featurd Content widget on blog.
 */
function widget($args, $instance) {
	extract( $args );
	
	// If not title, use the name of the category.
	if( !$instance["title"] ) {
		$category_info = get_category($instance["cat"]);
		$instance["title"] = $category_info->name;
	}
	
	// Get array of post info.
	query_posts("showposts=" . $instance["num"] . "&cat=" . $instance["cat"]);
	global $post; // So we can get the post ID
	
	echo $before_widget;
	
	// Widget title
	echo $before_title;
	if( (bool) $instance["title_link"] )
		echo '<a href="' . get_category_link($instance["cat"]) . '">' . $instance["title"] . '</a>';
	else
		echo $instance["title"];
	echo $after_title;

	echo '<ul>';
	$i = 0;
	while ( have_posts() ) : the_post();
	?>
		<li class="cat-posts-item <?php echo $post->ID; ?>
	<?php
		if ( $i==0 ) echo " first";
		elseif ( $i==($num-1) ) echo " last";
		echo '">';
		
		if ( (bool) $instance["thumbnail"] )
		{
	?>
		<div class="post-image-sidebar">
			<a class="post-frame-sidebar" href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"></a>
			<?php the_post_thumbnail('featured-side'); ?>
		</div>
	<?php } ?>
		
		<h4><a class="post_title" href="<?php echo the_permalink(); ?>" title="Permalink to <?php echo the_title(); ?>"><?php echo the_title(); ?></a></h4>
		<?php the_excerpt(); ?>
		
		</li>
	<?php
		$i++;
	endwhile;
	
	echo '</ul>';
	echo $after_widget;
}

/**
 * Form processing... Dead simple.
 */
function update($new_instance, $old_instance) {
    /*
    // Useless code until there is a callback for the widget removal.
    add_option("cafepress_menu_exclude", array());

    $cats = get_option("cafepress_menu_exclude"); // Get categories.

    if ( $new_instance["exclude"]!=$old_instance["exclude"] ) { // Exclusion changed.

        if ( (bool) $new_instance["exclude"] ) { // No -> Yes
            $cats[] = absint($new_instance["cat"]); // Add it to the list.
        } else { // Yes -> No
            // Remove old category from the list.
            $key = array_search($old_instance["cat"], $cats);
            unset($cats[$key]);
        }

    } elseif ( (bool) $new_instance["exclude"] ) {
        // Remove old
        $key = array_search($old_instance["cat"], $cats);
        unset($cats[$key]);

        // Add new
        $cats[] = absint($new_instance["cat"]); // Add it to the list.
    }

    update_option("cafepress_menu_exclude", $cats);
    */

    $new_instance["cat"] = absint( $new_instance["cat"] );
    $new_instance["exclude"] = (bool) $new_instance["exclude"];
    
	return $new_instance;
}

/**
 * The configuration form.
 */
function form($instance) {
?>
		<p>
			<label for="<?php echo $this->get_field_id("title"); ?>">
				<?php _e( 'Title' ); ?>:
				<input class="widefat" id="<?php echo $this->get_field_id("title"); ?>" name="<?php echo $this->get_field_name("title"); ?>" type="text" value="<?php echo esc_attr($instance["title"]); ?>" />
			</label>
		</p>
		
		<p>
			<label>
				<?php _e( 'Category' ); ?>:
				<?php wp_dropdown_categories( array( 'name' => $this->get_field_name("cat"), 'selected' => $instance["cat"] ) ); ?>
			</label>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id("num"); ?>">
				<?php _e('Number of posts to show'); ?>:
				<input style="width: 25px; text-align: center;" id="<?php echo $this->get_field_id("num"); ?>" name="<?php echo $this->get_field_name("num"); ?>" type="text" value="<?php echo absint($instance["num"]); ?>" />
			</label>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id("title_link"); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("title_link"); ?>" name="<?php echo $this->get_field_name("title_link"); ?>"<?php checked( (bool) $instance["title_link"], true ); ?> />
				<?php _e( 'Make widget title link' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("thumbnail"); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("thumbnail"); ?>" name="<?php echo $this->get_field_name("thumbnail"); ?>"<?php checked( (bool) $instance["thumbnail"], true ); ?> />
				<?php _e( 'Show post thumbnail' ); ?>
			</label>
		</p>

        <?php
        /*
            // Debug code...
            echo "<pre>";
            $tmp = get_option("widget_categorypostswidget");
            var_dump($tmp);
            echo "</pre>";
        */
        ?>

<?php

}

}

add_action( 'widgets_init', create_function('', 'return register_widget("CategoryPostsWidget");') );

?>